# **AbLang: A language model for antibodies**

-----------

# Install AbLang

AbLang is currently installed through github, using the following command.

~~~.sh
    pip install -U git+https://github.com/TobiasHeOl/AbLang.git
~~~

----------

# AbLang

Examples on use cases for AbLang can be found in the examples folder.
